@@ -2,11 +2,10 @@ _s3_client = None
 
 
 # improves speed for connecting on subsequent calls
-# TODO: find a better way to do this, like profiling?
 def _get_s3_client():
     global _s3_client
     import boto3
-    _s3_client = boto3.client('s3') if _s3_client is None else _s3_client
+    _s3_client = boto3.session.Session().client('s3') if _s3_client is None else _s3_client
     return _s3_client
 
 
