@@ -4,7 +4,7 @@ import json
 from hestia_earth.schema import SchemaType
 
 from ._s3_client import _load_from_bucket
-from .request import request_url, api_url, search_url
+from .request import request_url, api_url
 
 
 def _safe_get_request(url: str):
@@ -93,12 +93,11 @@ def find_node(node_type: SchemaType, args: dict, limit=10) -> list:
     query_args = list(map(lambda key: {'match': {key: args.get(key)}}, args.keys()))
     must = [{'match': {'@type': node_type.value}}]
     must.extend(query_args)
-    hits = requests.post(search_url(), json.dumps({
+    return requests.post(f"{api_url()}/search", json.dumps({
         'query': {'bool': {'must': must}},
         'limit': limit,
-        '_source': {'includes': ['name', '@id']}
-    }), headers=headers).json().get('hits', {}).get('hits', [])
-    return list(map(lambda res: res.get('_source'), hits))
+        'fields': ['name', '@id']
+    }), headers=headers).json().get('results', [])
 
 
 def find_node_exact(node_type: SchemaType, args: dict):
@@ -122,10 +121,10 @@ def find_node_exact(node_type: SchemaType, args: dict):
     query_args = list(map(lambda key: {'match': {f"{key}.keyword": args.get(key)}}, args.keys()))
     must = [{'match': {'@type': node_type.value}}]
     must.extend(query_args)
-    hits = requests.post(search_url(), json.dumps({
+    results = requests.post(f"{api_url()}/search", json.dumps({
         'query': {'bool': {'must': must}},
         'limit': 2,
-        '_source': {'includes': ['name', '@id']}
-    }), headers=headers).json().get('hits', {}).get('hits', [])
+        'fields': ['name', '@id']
+    }), headers=headers).json().get('results', [])
     # do not return a duplicate
-    return hits[0].get('_source') if len(hits) == 1 else None
+    return results[0] if len(results) == 1 else None
